@@ -6,11 +6,11 @@ Geo::Coder::Free::Config - Site independent configuration file
 
 =head1 VERSION
 
-Version 0.36
+Version 0.37
 
 =cut
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 # VWF is licensed under GPL2.0 for personal use only
 # njh@bandsman.co.uk
@@ -43,12 +43,11 @@ use File::Spec;
 
 =cut
 
-sub new {
-	my $proto = shift;
+sub new
+{
+	my $class = shift;
 	my %args = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
 
-	my $class = ref($proto) || $proto;
-
 	my $info = $args{info} || CGI::Info->new();
 
 	if($args{'logger'}) {
